## Worker
* [ x ] Add logger for Workers
* [ - ] HTTP logger
* [ x ] Add batch aggregation
* [ - ] Support email alert
* [ - ] Distribute, Data Steam using Redis, RabbitMQ
* [ x ] Multi-processes/models initialization
* [ x ] Get subprocess id and theirs status

## Connection
* [ x ] support RPC/TCP connections
* [ x ] support HTTP request

## API

* [ x ] Check service status
* [ x ] Get service process status
* [ - ] Web UI
* [ - ] Statistic GUI

## CLI

* [ x ] Add CLI
* [ x ] Terminate Workers
* [ - ] Add more Worker with specific GPU_ID
* [ x ] Restart Workers
* [ x ] Idle Workers
* [ x ] Start Funicorn Service

## MISC
* [ x ] Colored logger
* [ - ] Centralize Config
